@@ -4,10 +4,14 @@ from asyevent.callback import Callback
 from asyevent.event import Event
 from asyevent.command import Command
 
-from asyevent.exceptions import CommandNotFound, EventNotFound, CommandAlreadyRegistered, EventAlreadyRegistered
+from asyevent.exceptions import (
+    CommandNotFound,
+    EventNotFound,
+    CommandAlreadyRegistered,
+    EventAlreadyRegistered,
+)
 
-from typing import Callable, Optional, Union, List
-from copy import copy
+from typing import Callable, Optional, Union, List, Tuple
 
 
 class EventManager:
@@ -19,6 +23,7 @@ class EventManager:
     need a `event_manager` variable, to be executed directly with the error handler provided.
 
     """
+
     def __init__(self):
         """
         Initialises an event manager.
@@ -31,30 +36,35 @@ class EventManager:
         # For all events and commands that defines `handle_errors` set to True, their
         # exceptions are handled in this event.
         # Passed parameters are : the exception, the event, the callback, args, **kwargs.
-        self.error_handler = self.create_event('<error_handler>', handle_errors=False)
+        self.error_handler = self.create_event("<error_handler>", handle_errors=False)
 
     @property
-    def events(self) -> List[Event]:
+    def events(self) -> Tuple[Event]:
         """
-        Property that makes registered events immutable from outside.
+        Returns all registered events.
 
-        :return: A copy of registered events.
+        :return: A tuple of events.
         """
-        return copy(self._events)
+        return tuple(self._events)
 
     @property
-    def commands(self) -> List[Command]:
+    def commands(self) -> Tuple[Command]:
         """
-        Property that makes registered commands immutable from outside.
+        Returns all registered commands.
 
-        :return: A copy of registered commands.
+        :return: A tuple of commands.
         """
-        return copy(self._commands)
+        return tuple(self._commands)
 
     def as_command(
-            self, name: str = None, handle_errors: bool = True,
-            multiple_callbacks: bool = True, priority: int = 1, **options
-    ) -> Callable[[Callable], Callback]:
+        self,
+        *,
+        name: str = None,
+        handle_errors: bool = True,
+        multiple_callbacks: bool = True,
+        priority: int = 1,
+        **options
+    ) -> Callable[[Union[Callable, Callback]], Callback]:
         """
         A decorator which registers a coroutine as a callback of this command.
 
@@ -66,43 +76,12 @@ class EventManager:
         :return: A callback.
         """
 
-        def decorator(coroutine: Union[Callable, Callback]) -> Callback:
+        def decorator(callback: Union[Callable, Callback]) -> Callback:
             command = self.create_command(
-                coroutine=coroutine,
+                callback,
                 name=name,
                 handle_errors=handle_errors,
                 multiple_callbacks=multiple_callbacks,
-                is_classmethod=False,
-                priority=priority,
-                **options
-            )
-
-            return command.initial_callback
-
-        return decorator
-
-    def as_class_command(
-            self, name: str = None, handle_errors: bool = True,
-            multiple_callbacks: bool = True, priority: int = 1, **options
-    ) -> Callable[[Callable], Callback]:
-        """
-        A decorator which registers a classmethod coroutine as a callback of this command.
-
-        :param priority: When an event is raised, associated callbacks will be invoked by ascending priority order.
-        :param name: The command name. Coroutine name by default.
-        :param handle_errors: Determines if exceptions are handle into the error handler event.
-        :param multiple_callbacks: Does the command allow multiple callbacks.
-
-        :return: A callback.
-        """
-
-        def decorator(coroutine: Union[Callable, Callback]) -> Callback:
-            command = self.create_command(
-                coroutine=coroutine,
-                name=name,
-                handle_errors=handle_errors,
-                multiple_callbacks=multiple_callbacks,
-                is_classmethod=True,
                 priority=priority,
                 **options
             )
@@ -112,30 +91,34 @@ class EventManager:
         return decorator
 
     def create_command(
-            self, coroutine: Union[Callable, Callback], name: str = None, handle_errors: bool = True,
-            multiple_callbacks: bool = True, is_classmethod: bool = False, priority: int = 1, **options
+        self,
+        callback: Union[Callable, Callback],
+        *,
+        name: str = None,
+        handle_errors: bool = True,
+        multiple_callbacks: bool = True,
+        priority: int = 1,
+        **options
     ) -> Command:
         """
         Registers a coroutine as a `command` event.
         The purpose of using this instead of `Event.as_callback` is dynamic event names.
 
         :param multiple_callbacks: Does the command allow multiple callbacks associated to.
-        :param coroutine: Coroutine which will be called when the command event is raised.
+        :param callback: Coroutine which will be called when the command event is raised.
         :param name: The command name. Coroutine name by default.
         :param handle_errors: Determines if exceptions are handle into the error handler event.
-        :param is_classmethod: Defines if the callback must be invoked with a `self` parameter.
         :param priority: When an event is raised, associated callbacks will be invoked by ascending priority order.
         :param options: Callback options
 
         :return: A command.
         """
         command = Command(
-            coroutine=coroutine,
+            callback,
             event_manager=self,
             name=name,
             handle_errors=handle_errors,
             multiple_callbacks=multiple_callbacks,
-            is_classmethod=is_classmethod,
             priority=priority,
             **options
         )
@@ -143,7 +126,9 @@ class EventManager:
 
         return command
 
-    def create_event(self, name: str, handle_errors: bool = True, multiple_callbacks: bool = True) -> Event:
+    def create_event(
+        self, name: str, *, handle_errors: bool = True, multiple_callbacks: bool = True
+    ) -> Event:
         """
         Creates an event associated to the manager.
 
@@ -157,13 +142,15 @@ class EventManager:
             name=name,
             event_manager=self,
             handle_errors=handle_errors,
-            multiple_callbacks=multiple_callbacks
+            multiple_callbacks=multiple_callbacks,
         )
         self._events.append(event)
 
         return event
 
-    def get_command(self, name: str, case_sensitive: bool = True) -> Optional[Command]:
+    def get_command(
+        self, name: str, *, case_sensitive: bool = True
+    ) -> Optional[Command]:
         """
         Get a command by its name. The command must be associate to this manager.
 
@@ -173,10 +160,11 @@ class EventManager:
         :return: A command if found.
         """
         return {
-            cmd.command_name.lower() if not case_sensitive else cmd.command_name: cmd for cmd in self._commands
+            cmd.command_name.lower() if not case_sensitive else cmd.command_name: cmd
+            for cmd in self._commands
         }.get(name.lower() if not case_sensitive else name)
 
-    def get_event(self, name: str, case_sensitive: bool = True) -> Optional[Event]:
+    def get_event(self, name: str, *, case_sensitive: bool = True) -> Optional[Event]:
         """
         Get an event by its name. The event must be associate to this manager.
 
@@ -186,10 +174,11 @@ class EventManager:
         :return: An event if found.
         """
         return {
-            event.event_name.lower() if not case_sensitive else event.event_name: event for event in self._events
+            event.event_name.lower() if not case_sensitive else event.event_name: event
+            for event in self._events
         }.get(name.lower() if not case_sensitive else name)
 
-    def replace_command_name(self, name: str, new_name: str):
+    def replace_command_name(self, name: str, *, new_name: str):
         """
         Replace a command name.
 
@@ -283,7 +272,9 @@ class EventManager:
 
         self.remove_command(command)
 
-    async def invoke_command(self, name: str, *args, case_sensitive: bool = True, **kwargs):
+    async def invoke_command(
+        self, name: str, *args, case_sensitive: bool = True, **kwargs
+    ):
         """
         Invokes a command by its name.
 
@@ -301,7 +292,9 @@ class EventManager:
 
         await command.raise_event(*args, **kwargs)
 
-    async def raise_event(self, name: str, *args, case_sensitive: bool = True, **kwargs):
+    async def raise_event(
+        self, name: str, *args, case_sensitive: bool = True, **kwargs
+    ):
         """
         Raises an event by its name.
 
