@@ -3,32 +3,35 @@ from asyevent.callback import Callback
 from typing import List
 
 
-class EventWrapperMixin:
+class EventWrapper:
     """
     !! Implement this class to create callbacks from classmethods !!
 
-    Mixin class which implements a way to deal with classmethod callbacks.
+    Implements a way to deal with classmethod coroutines.
     """
+
     def __init__(self):
         self.callbacks: List[Callback] = []
 
-    def init_callbacks(self):
+        # initialises callbacks
+        self._init_callbacks()
+
+    def _init_callbacks(self):
         """
-        !! Use this method to make classmethod callbacks work !!
-
         Pass to all contained callbacks a `self instance` parameter.
+        Use this if a callback has been added after the instance initialisation.
 
-        :raise TypeError: If none classmethod callbacks are registered.
+        :raise TypeError: If a registered callback is not a classmethod.
         """
 
         for attr in dir(self):
-            if attr != self.init_callbacks.__name__:  # avoid recursive calls
+            if attr != self._init_callbacks.__name__:  # avoid recursive calls
                 if isinstance(getattr(self, attr), Callback):
                     self.callbacks.append(getattr(self, attr))
 
         for callback in self.callbacks:
             if not callback.is_classmethod:
-                raise TypeError('Wrapper\'s callbacks must be declared as class callbacks.')
+                raise TypeError("Wrapper's callbacks must be as class callbacks.")
 
             callback.wrapper = self
 
